# Integrations

Framework integrations are the main way to use *svcs*.
Thanks to its flexibility, it's possible to integrate with any framework in their own most idiosyncratic way.

Here's documentation on those we ship and how you can write your own.

```{toctree}
:maxdepth: 1

aiohttp
fastapi
flask
pyramid
starlette
custom
```
